@@ -15,6 +15,34 @@ default_feature_engineering_methods = ['all_features','anova', 'correlation', 'p
 default_hyperparamter_methods = ['standard','grid_search', 'random_search', 'bayesian_tpe']
 models = list(map_model.keys())
 
+name_holder = {
+    'LinearRegression' : 'Linear Regression',
+    'Ridge' : "Ridge Regression",
+    'Lasso' : "Lasso Regression",
+    'DecisionTreeRegressor' : 'Decision Tree Regression',
+    'RandomForestRegressor' : 'Random Forest Regression',
+    'AdaBoostRegressor' : 'AdaBoost Regression',
+    'ExtraTreesRegressor' : 'Extra Trees Regression',
+    'BaggingRegressor' : 'Bagging Regression',
+    'GradientBoostingRegressor' : 'Gradient Boosting Regression',
+    'LogisticRegression' : 'Logistic Regression',
+    'RandomForestClassifier' : 'Random Forest Classifier',
+    'AdaBoostClassifier' : 'AdaBoost Classifier',
+    'BaggingClassifier' : 'Bagging Classifier',
+    'GradientBoostingClassifier' : 'Gradient Boosting Classifier',
+    'ExtraTreesClassifier' : 'Extra Trees Classifier',
+    'DecisionTreeClassifier' : 'Decision Tree Classifier',
+    'standard':'No HPO',
+    'grid_search':'Grid Search',
+    'random_search':'Random Search',
+    'bayesian_tpe':'Bayesian Optimization',
+    'all_features' : 'No Feature Engineering',
+    'anova_regressor' : 'ANOVA',
+    'anova_classifier' : 'ANOVA',
+    'correlation' : 'Correlation Method',
+    'pca' : 'Principal Component Analysis',
+    'select_from_model' : 'Select from Model'
+}
 
 techniques_dict = {
     mod.__name__ : mod for mod in [anova_classifier, anova_regressor, correlation, pca, select_from_model, grid_search, random_search, bayesian_tpe, bayesian_gp]
@@ -170,11 +198,13 @@ def auto_trainer(dataset,label,task,feature_engineering_methods=default_feature_
                     column_names = ['Estimator', 'Feature Engineering Method', 'Hyperparameter Optimization Method']
                     column_names.extend(list(model_metrics.keys()))
                     model_metrics = list(map(lambda value : round(value, 4), model_metrics.values()))
-                    stats.append([model,model_name,feature_engineering_method,hpo_method]+list(model_metrics))
+                    #change names
+                    stats.append([model,name_holder[model_name],name_holder[feature_engineering_method],name_holder[hpo_method]]+list(model_metrics))
 
 
                 dataset = original_dataset.copy()
     
+    print(stats)
     #To sort on basis of metric provided
     if sortby:
         index = column_names.index(sortby) + 1
